@@ -9,8 +9,9 @@ import os
 import os.path
 import glob
 import math
-import ConfigParser
+import ConfigParser as configparser
 import warnings
+import pkg_resources
 #graphing
 import matplotlib.pyplot as plt
 
@@ -73,18 +74,41 @@ def make_cfg(options, replacement_values, base_config, out_filename):
 
     Used to create a sim.cfg config file from a cmp.cfg comparison config.
     """
-    # read in config file
-    config = ConfigParser.RawConfigParser()
-    with open(base_config, 'r') as in_file:
-        config.readfp(in_file, base_config)
+    def replace_value(config, master_config, option, value):
+        """Replaces a value in a configuration file.
 
-    # replace values
-    for option, value in zip(options, replacement_values):
+        Checks to make sure the option exists either in the file,
+        or in the master config file.
+        """
         for section in config.sections():
             if config.has_option(section, option):
                 config.set(section, option, value)
-                break
+                return
+        # option not found in config file
+        # see if it is in master config file
+        for section in master_config.sections():
+            if master_config.has_option(section, option):
+                try:
+                    config.set(section, option, value)
+                except configparser.NoSectionError:
+                    config.add_section(section)
+                    config.set(section, option, value)
+                return
+        # option not found in master config file
+        raise ValueError('Unknown configuration option: {}'.format(option))
 
+    # read in config file
+    config = configparser.RawConfigParser()
+    with open(base_config, 'r') as in_file:
+        config.readfp(in_file, base_config)
+    # read in master config file
+    master_config = configparser.RawConfigParser()
+    with pkg_resources.resource_stream('pykaryote',
+                        os.path.join('configs', 'master.cfg')) as master_file:
+        master_config.readfp(master_file)
+    # replace values
+    for option, value in zip(options, replacement_values):
+        replace_value(config, master_config, option, value)
     # write output
     with open(out_filename, 'w') as out_file:
         config.write(out_file)
